import { PropertyValueMap } from "lit";
import { Ref } from "lit/directives/ref.js";
import { FormBuilderConfig, FormBuilderState, FormBuilderValues, FormBuilderField, FormBuilderGenericValidationRule } from "./f-form-builder-types";
import { FRoot } from "@cldcvr/flow-core/src/mixins/components/f-root/f-root";
export declare class FFormBuilder extends FRoot {
    /**
     * css loaded from scss file
     */
    static styles: import("lit").CSSResult[];
    /**
     * @attribute formbuilder config
     */
    config: FormBuilderConfig;
    /**
     * @attribute key value pair of values
     */
    values: FormBuilderValues;
    /**
     * Internal state of formbuilder
     */
    state: FormBuilderState;
    /**
     * form reference
     */
    formRef: Ref<HTMLFormElement>;
    render(): import("lit-html").TemplateResult<1>;
    /**
     * handle input event of form
     */
    handleFormChange(event: Event): void;
    /**
     * build/render form based on config
     */
    build(): import("lit-html").TemplateResult<1>;
    onSubmit(event: SubmitEvent): void;
    submit(): void;
    /**
     * check if condition is satisfying for any element
     */
    checkAllShowConditions(): void;
    /**
     * validate whole form
     * @param silent
     */
    validateForm(silent?: boolean): void;
    /**
     * render field based on field config
     * @param fields
     */
    buildFields(groupname: string, fields: Record<string, FormBuilderField>): import("lit-html").TemplateResult<1>;
    /**
     * updated hook of lit element
     * @param _changedProperties
     */
    protected updated(_changedProperties: PropertyValueMap<any> | Map<PropertyKey, unknown>): void;
    emitStateChange(): void;
    /**
     * Add/Display initial values given by user
     * @param inputElement
     * @param name
     * @param index
     * @param isMultiple
     */
    bindValues(inputElement: HTMLInputElement | undefined, name: string): void;
    /**
     * validation rules listener added on `input` event.
     * @param inputElement
     */
    bindValidation(inputElement: HTMLInputElement | undefined, name: string): void;
    /**
     *
     * @param inputElement ref of field
     * @param silent if true then errors are not rendered, they are added in state only
     */
    validateField(name: string, inputElement: HTMLInputElement, silent?: boolean, filter?: (r: FormBuilderGenericValidationRule) => boolean): void;
}
